import { useEffect } from "react";
/*
    This hook detects when the user makes any click, and then calls the passed function.
    
    When noActionClickElements are provided or a noActionClassName, any click on one of the
    noActionClickElements or on an element with the class noActionClassName, will not trigger the onClick function.

    This is used to close the dropdown when the user makes any click.

    Adapted from https://stackoverflow.com/questions/54560790/detect-click-outside-react-component-using-hooks
*/
export function useCallOnAnyClick(onClick, noActionClickElements, noActionClassName) {
    const handleClick = (event) => {
        const targetNode = event.target;
        // If the click was on the noActionClassName, return without calling onClick
        if (noActionClassName && targetNode.nodeType === Node.ELEMENT_NODE) {
            const targetElement = targetNode;
            if (targetElement.classList.contains(noActionClassName)) {
                return;
            }
        }
        // If the click was on any of the noActionClickElements,
        // then return without calling onClick
        if (noActionClickElements !== undefined) {
            let returnWithoutClick = false;
            noActionClickElements.forEach(element => {
                if (element && element.current !== null && element.current.contains(targetNode)) {
                    returnWithoutClick = true;
                }
            });
            if (returnWithoutClick) {
                return;
            }
        }
        /*
            We delay actually calling of the function by 100 miliseconds, just in case the user's click is
            actually on the dropdown open/close button. This makes sure that we don't close and then
            immediately reopen the component.

            It is an ugly hack, but it appears to work for now!
        */
        setTimeout(() => {
            onClick();
        }, 100);
    };
    useEffect(() => {
        document.addEventListener('click', handleClick, true);
        return () => {
            document.removeEventListener('click', handleClick, true);
        };
    });
}
//# sourceMappingURL=useCallOnAnyClick.js.map